;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;British Crown Copyright (c) 2012, the Met Office All rights reserved.
;
;Redistribution and use in source and binary forms, with or without 
;modification, are permitted provided that the following conditions 
;are met:
;
;Redistributions of source code must retain the above copyright notice, 
;this list of conditions and the following disclaimer. 
;
;Redistributions in binary form must reproduce the above copyright 
;notice, this list of conditions and the following disclaimer in the 
;documentation and/or other materials provided with the distribution. 
;
;Neither the name of the Met Office nor the names of its contributors 
;may be used to endorse or promote products derived from this software 
;without specific prior written permission. 
;
;THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
;"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
;LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
;A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
;HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
;SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
;LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
;DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
;THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
;(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
;OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO CALCULATE_SPECIFIC_HUM, temperatures, dewpoints, pressure, specific_humidity, mdi
;************************************************************
; NAME:
;     CALCULATE_SPECIFIC_HUM
;
; PURPOSE:
;     Calculate the specific humidity series for a station
;
; CALLING SEQUENCE:
;     CALCULATE_SPECIFIC_HUM, temperatures, dewpoints, pressure, specific_humidity, mdi
;
; INPUTS:
;     temperatures - array containing temperature data
;
;     dewpoints - array containing dewpoint temperature data
;
;     pressure - array containing pressure data
;
;     mdi - missing data indicator
;
; METHOD:
;     Calculates vapour pressure, and from there, the specific humidity
;
; OUTPUTS:
;     specific_humidity - empty array to contain specific humidity data
;     
; RESTRICTIONS:
;
;
;   
; HISTORY:
;      218 - Written, 6 September 2011 RJHD
;      237 - SVN information added to header
;            16 November 2011 RJHD
;************************************************************************
;                    SVN Info
;$Rev:: 303                                           $:  Revision of last commit
;$Author:: rdunn                                      $:  Author of last commit
;$Date:: 2012-06-14 14:02:44 +0100 (Thu, 14 Jun 2012) $:  Date of last commit
;************************************************************************
;                                 START
;************************************************************************



; size of arrays
nhours=N_ELEMENTS(temperatures)

; set up empty arrays
vp_exponent=FLTARR(nhours)
vp_exponent[*]=mdi
vp_f=FLTARR(nhours)
vp_f[*]=mdi
vapour_pressure=FLTARR(nhours)
vapour_pressure[*]=mdi

; NB - only water bulb calculations done so far

; Calculate vapour pressure in bits, where valid data exists to work with
good_dp=WHERE(dewpoints NE mdi)

vp_exponent[good_dp]=((dewpoints[good_dp]*(18.729-(dewpoints[good_dp]/227.3)))/(257.87+dewpoints[good_dp]))

good_p=WHERE(dewpoints NE mdi)

vp_f[good_p]=1.+7.e-4+(3.46e-6*pressure[good_p])

good_vp=WHERE(vp_f NE mdi AND vp_exponent NE mdi)

vapour_pressure[good_vp]=6.1121*vp_f[good_vp]*EXP(vp_exponent[good_vp])

; from vapour pressure, calculate specific humidity
good_vp=WHERE(vapour_pressure NE mdi AND pressure NE mdi)

specific_humidity[good_vp]=1000.*((0.622*vapour_pressure[good_vp])/(pressure[good_vp]-((1.-0.622)*vapour_pressure[good_vp]))) ;g/kg


RETURN

END
;************************************************************************
;                                 END
;************************************************************************
