;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;British Crown Copyright (c) 2012, the Met Office All rights reserved.
;
;Redistribution and use in source and binary forms, with or without 
;modification, are permitted provided that the following conditions 
;are met:
;
;Redistributions of source code must retain the above copyright notice, 
;this list of conditions and the following disclaimer. 
;
;Redistributions in binary form must reproduce the above copyright 
;notice, this list of conditions and the following disclaimer in the 
;documentation and/or other materials provided with the distribution. 
;
;Neither the name of the Met Office nor the names of its contributors 
;may be used to endorse or promote products derived from this software 
;without specific prior written permission. 
;
;THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
;"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
;LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
;A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
;HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
;SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
;LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
;DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
;THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
;(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
;OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO COMPOSITEINFO, CompositeFile, CompositeList
;************************************************************************
; 

; NAME:
;     COMPOSITEINFO
;
; PURPOSE:
;     To read in list of composites and return an array to allow
; comparisons to be made. 
;
; CALLING SEQUENCE:
;     compositeinfo, compositefile, compositelist
;
; INPUTS:
;     compositefile - file containing list of composites/composites
;
; OUTPUTS:
;     compositelist - array containing names of stations making up the composites
;
;
; RESTRICTIONS:
;
; COMMENTS
;
;
; HISTORY:
;     # 242 - created
;             21 November 2011 RJHD
;     # 263 - Adjusted array size to allow stop to work in qc_all_vars_internal
;             14 December 2011 RJHD
;
;
;************************************************************************
;                    SVN Info
;$Rev:: 317                                           $:  Revision of last commit
;$Author:: rdunn                                      $:  Author of last commit
;$Date:: 2012-08-29 17:45:37 +0100 (Wed, 29 Aug 2012) $:  Date of last commit
;************************************************************************
;                                 START
;************************************************************************

;****************************
; Firstly just read in each line of the file as a long string
; into a single column array
;****************************
TotalComposites=NLINES(CompositeFile)

CompositesString=STRARR(TotalComposites)

d=0
Dups=''
OPENR,1,CompositeFile
WHILE NOT EOF(1) DO BEGIN

   READF,1,Dups,FORMAT='(A300)'
   
   CompositesString[d]=STRTRIM(Dups)
   d=d+1
ENDWHILE
CLOSE,1

;****************************
; Find the maximum number of station which make up
;  a composite, and create a rectangular array
;  of this length + 1 as the final empty entry is used as a stop signal
;****************************
MaxMerge=(MAX(STRLEN(compositesstring))+1)/13+1

CompositeList=STRARR(N_ELEMENTS(compositesstring),MaxMerge)
CompositeList[*,*]='-'

ID_Len=13

;****************************
; For each list of composites, split and place into array.
;****************************
FOR counter=0,N_ELEMENTS(compositesstring)-1 DO BEGIN
   
   Sstart=0
  
   stn=0
   
   WHILE 1 DO BEGIN
      
      CompositeList[counter,stn]=$
         STRMID(compositesstring[counter],Sstart,6)+'-'+$
         STRMID(compositesstring[counter],Sstart+7,5)

      Sstart=Sstart+ID_Len
      stn=stn+1
      IF Sstart GT STRLEN(compositesstring[counter]) THEN BREAK

   ENDWHILE

ENDFOR


RETURN

END

;************************************************************************
;                                 END
;************************************************************************
