;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;British Crown Copyright (c) 2012, the Met Office All rights reserved.
;
;Redistribution and use in source and binary forms, with or without 
;modification, are permitted provided that the following conditions 
;are met:
;
;Redistributions of source code must retain the above copyright notice, 
;this list of conditions and the following disclaimer. 
;
;Redistributions in binary form must reproduce the above copyright 
;notice, this list of conditions and the following disclaimer in the 
;documentation and/or other materials provided with the distribution. 
;
;Neither the name of the Met Office nor the names of its contributors 
;may be used to endorse or promote products derived from this software 
;without specific prior written permission. 
;
;THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
;"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
;LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
;A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
;HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
;SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
;LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
;DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
;THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
;(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
;OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

pro map_duplicates
;------------------------------------------------------------------------
; NAME:
;     MAP_DUPLICATES
;
; PURPOSE:
;     To plot locations of assigned duplicates in the un-selected HadISD
;
; CALLING SEQUENCE:
;     map_duplicates
;
; INPUTS:
;     None
;
; METHOD:
;     Reads ish-history files and duplicates file and outputs a ps file
;
; OUTPUTS:
;     One .ps file
;
; RESTRICTIONS:
;
;     
;   
; HISTORY:
;      #267 - copied from station_selection on KMW.  Adjusted to RJHD
;             file system
;      #271 - Added duplicate stations output from Test 1 to composite
;             stations output.  Also changed to Robinson projection
;             and removed elevation information (this_colour=200 if >1000)
;************************************************************************
;                    SVN Info
;$Rev:: 317                                           $:  Revision of last commit
;$Author:: rdunn                                      $:  Author of last commit
;$Date:: 2012-08-29 17:45:37 +0100 (Wed, 29 Aug 2012) $:  Date of last commit
;
;************************************************************************
;                                 START
;************************************************************************



ON_ERROR,1

; Program plots as a map those points which meet or exceed the given
; criteria given in criteria array on pass and outputs to a postscript
; plot file for subsequent consideration.


; Read in the full list of location info first so we have something to match against.
station_ids=STRARR(28986)
lats=FLTARR(28986)
lats(*)=-999.
lons=FLTARR(28986)
lons(*)=-999.
elevs=FLTARR(28986)
elevs(*)=-999.

OPENR,1,'./ish-history.txt'
line=''
FOR i=0,16 DO READF,1,line
FOR st=0,28162 DO BEGIN
  READF,1,line
  station_ids(st)=STRCOMPRESS(STRMID(line,0,6)+'-'+STRMID(line,7,5),/remove_all)
  temp=STRCOMPRESS(STRMID(line,58,6),/remove_all)
  IF STRLEN(temp) GE 2 THEN lats(st)=FLOAT(temp)/1000.
  temp=STRCOMPRESS(STRMID(line,65,7),/remove_all)
  IF STRLEN(temp) GE 2 THEN lons(st)=FLOAT(temp)/1000.
  temp=STRCOMPRESS(STRMID(line,74,6),/remove_all)
  IF STRLEN(temp) GE 2 THEN elevs(st)=FLOAT(temp)/10.
ENDFOR
CLOSE,1
 
OPENR,1,'./isd-history-additional-data.txt'
FOR i=0,20 DO READF,1,line
FOR st=28163,28985 DO BEGIN
  READF,1,line
  station_ids(st)=STRCOMPRESS(STRMID(line,0,6)+'-'+STRMID(line,8,5),/remove_all)
  temp=STRCOMPRESS(STRMID(line,80,6),/remove_all)
  IF STRLEN(temp) GE 2 THEN lats(st)=FLOAT(temp)/1000.
  temp=STRCOMPRESS(STRMID(line,88,7),/remove_all)
  IF STRLEN(temp) GE 2 THEN lons(st)=FLOAT(temp)/1000.
  temp=STRCOMPRESS(STRMID(line,96,6),/remove_all)
  IF STRLEN(temp) GE 2 THEN elevs(st)=FLOAT(temp)/10.
ENDFOR
CLOSE,1
;
; Missing fix on elevations
points=WHERE(elevs GE 6000.)
elevs(points)=-999.

SET_PLOT,'ps'
Device,file='images/duplicates.ps',/color,/helvetica
!P.font=0
!P.Position=[0.08,0.08,0.96,0.9]
plotsym,0,0.55,/fill
RESTORE_COLOURS,'shortbow'
Map_set,0,0,limit=[-90,-180,90,180],/noborder,color=0,/noerase,/robinson,/grid, glinestyle=2
map_continents,/coasts, color=0
; Read in the criteria_match.txt file and for each station that matches
; plot a cross on the map and output to the text file.
OPENR,1,'duplicates_ordered.txt'
lat=0.
lon=0.
station_id=''
total_stns=0
WHILE NOT EOF(1) DO BEGIN
  ; Read in the current line
  READF,1,station_id,FORMAT='(A12)'
  station_id=STRMID(station_id,0,6)+'-'+STRMID(station_id,7,5)
  match=WHERE(station_ids EQ station_id, c)
  this_color=7
  IF c LE 0 THEN STOP,'non-match found'
  IF elevs(match(0)) LE 1000. THEN BEGIN
    this_color=7
  ENDIF ELSE IF elevs(match(0)) LE 2000. THEN BEGIN
    this_color=7
  ENDIF
  PLOTS,lons(match(0)),lats(match(0)),psym=8,color=this_color 
  total_stns=total_stns+1  
ENDWHILE
CLOSE,1

PLOTS,[-179.9,0],[89.9,89.9],color=0
PLOTS,[0,179.9],[89.9,89.9],color=0
PLOTS,[-179.9,0],[-89.9,-89.9],color=0
PLOTS,[0,179.9],[-89.9,-89.9],color=0

XYOUTS,-180,85,'90N ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,43,'45N ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-2,'0 ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-47,'45S  ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-89,'90S      ',alignment=1,charsize=0.9,color=0

XYOUTS,0.26,0.05,'180W',/normal,charsize=0.9,color=0
XYOUTS,0.38,0.05,'90W',/normal,charsize=0.9,color=0
XYOUTS,0.512,0.05,'0',/normal,charsize=0.9,color=0
XYOUTS,0.64,0.05,'90E',/normal,alignment=1,charsize=0.9,color=0
XYOUTS,0.78,0.05,'180E',/normal,alignment=1,charsize=0.9,color=0


XYOUTS,0.02,0.02,'Total stations: '+STRCOMPRESS(STRING(total_stns),/remove_all),/normal
XYOUTS,0.5,0.95,'Locations of Assigned Composites',/normal,alignment=0.5

DEVICE,/close_file

;*******************************************************
;
;*******************************************************

SET_PLOT,'ps'
Device,file='images/duplicates_test1.ps',/color,/helvetica
!P.font=0
!P.Position=[0.08,0.08,0.96,0.9]
plotsym,0,0.55,/fill
RESTORE_COLOURS,'shortbow'
Map_set,0,0,limit=[-90,-180,90,180],/noborder,color=0,/noerase,/robinson,/grid, glinestyle=2
map_continents,/coasts, color=0
; Read in the criteria_match.txt file and for each station that matches
; plot a cross on the map and output to the text file.
OPENR,1,'final_remove_dups_MAY09.txt'
lat=0.
lon=0.
station_id=''
total_stns=0
WHILE NOT EOF(1) DO BEGIN
  ; Read in the current line
  READF,1,station_id,FORMAT='(A200)'
  station_id=STRMID(station_id,0,6)+'-'+STRMID(station_id,7,5)
  match=WHERE(station_ids EQ station_id, c)
  this_color=7
  IF c LE 0 THEN STOP,'non-match found'
  IF elevs(match(0)) LE 1000. THEN BEGIN
    this_color=7
  ENDIF ELSE IF elevs(match(0)) LE 2000. THEN BEGIN
    this_color=7
  ENDIF
  PLOTS,lons(match(0)),lats(match(0)),psym=8,color=this_color 
  total_stns=total_stns+1  
ENDWHILE
CLOSE,1

PLOTS,[-179.9,0],[89.9,89.9],color=0
PLOTS,[0,179.9],[89.9,89.9],color=0
PLOTS,[-179.9,0],[-89.9,-89.9],color=0
PLOTS,[0,179.9],[-89.9,-89.9],color=0

XYOUTS,-180,85,'90N ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,43,'45N ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-2,'0 ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-47,'45S  ',alignment=1,charsize=0.9,color=0
XYOUTS,-180,-89,'90S      ',alignment=1,charsize=0.9,color=0

XYOUTS,0.26,0.05,'180W',/normal,charsize=0.9,color=0
XYOUTS,0.38,0.05,'90W',/normal,charsize=0.9,color=0
XYOUTS,0.512,0.05,'0',/normal,charsize=0.9,color=0
XYOUTS,0.64,0.05,'90E',/normal,alignment=1,charsize=0.9,color=0
XYOUTS,0.78,0.05,'180E',/normal,alignment=1,charsize=0.9,color=0

XYOUTS,0.02,0.02,'Total stations: '+STRCOMPRESS(STRING(total_stns),/remove_all),/normal
XYOUTS,0.5,0.95,'Locations of Duplicate Stations',/normal,alignment=0.5

DEVICE,/close_file

SET_PLOT,'X'
 
RETURN
 
END
;************************************************************************
;                                 End
;************************************************************************
