;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;British Crown Copyright (c) 2012, the Met Office All rights reserved.
;
;Redistribution and use in source and binary forms, with or without 
;modification, are permitted provided that the following conditions 
;are met:
;
;Redistributions of source code must retain the above copyright notice, 
;this list of conditions and the following disclaimer. 
;
;Redistributions in binary form must reproduce the above copyright 
;notice, this list of conditions and the following disclaimer in the 
;documentation and/or other materials provided with the distribution. 
;
;Neither the name of the Met Office nor the names of its contributors 
;may be used to endorse or promote products derived from this software 
;without specific prior written permission. 
;
;THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
;"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
;LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
;A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
;HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
;SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
;LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
;DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
;THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
;(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
;OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

PRO MAP_WRAPPER, suffix, region=region


;------------------------------------------------------------------------
; NAME:
;     MAP_WRAPPER
;
; PURPOSE:
;     To cycle through all tests and plot the geographical
;     distribution of failures.
;
; CALLING SEQUENCE:
;     map_wrapper, suffix, region
;
; INPUTS:
;     suffix - which stage of the QC process to plot
;              internal/external/mask/internal2/external2/mask2
;
;     region - optional keyword to pass onto the plotting routine.
;
; METHOD:
;     Calls plot_qc_fail_map_rd once for each test.
;
; OUTPUTS:
;     One .eps file per test
;
; RESTRICTIONS:
;
;     
;   
; HISTORY:
;      #186 - Created
;           17 February 2011 RJHD
;      #237 - SVN information added to header
;             16 November 2011 RJHD
;************************************************************************
;                    SVN Info
;$Rev:: 303                                           $:  Revision of last commit
;$Author:: rdunn                                      $:  Author of last commit
;$Date:: 2012-06-14 14:02:44 +0100 (Thu, 14 Jun 2012) $:  Date of last commit
;

;************************************************************************
;                                 START
;************************************************************************


test_arr=['DUP','TFV','DFV','SFV','DNL','TGP','DGP','SGP','TRC','DRC',$
	  'WRC','PRC','TSS','DSS','WSS','PSS','HTS','HDS','HWS','HPS',$
	  'DTS','DDS','DWS','DPS','TCM','DCM','PCM','TSP','DSP','PSP',$
	  'SSS','DPD','DCF','CUOT','CUOL','CUOM','CUOH','CST','FLW','FMC',$
	  'NGC','TOT','DOT','SOT','TMB','DMB','SMB','WMB','BBB','CMB',$
	  'LMB','MMB','HMB','BMB','OCT','OCD','OCW','OCS','TVR','DVR',$
	  'SVR','STR_T','STR_D','STR_W','STR_S','ALL_T','ALL_Td','ALL_SLP','ACL']


ntests=N_ELEMENTS(test_arr)

JulDay=SYSTIME(/JULIAN)

CALDAT,JulDay,Month,Day,Year

date=STRING(Year,FORMAT='(I4.4)')+STRING(Month,FORMAT='(I2.2)')+STRING(Day,FORMAT='(I2.2)')

summary_filename='all_fails_summary_'+date+'.dat'

SPAWN, 'touch '+summary_filename

FOR i=0,ntests-1 DO BEGIN
    PLOT_QC_FAIL_MAP_RD, suffix, test_arr[i], region=region, /summary


ENDFOR

RETURN

END

;************************************************************************
;                                 END
;************************************************************************
