;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;British Crown Copyright (c) 2012, the Met Office All rights reserved.
;
;Redistribution and use in source and binary forms, with or without 
;modification, are permitted provided that the following conditions 
;are met:
;
;Redistributions of source code must retain the above copyright notice, 
;this list of conditions and the following disclaimer. 
;
;Redistributions in binary form must reproduce the above copyright 
;notice, this list of conditions and the following disclaimer in the 
;documentation and/or other materials provided with the distribution. 
;
;Neither the name of the Met Office nor the names of its contributors 
;may be used to endorse or promote products derived from this software 
;without specific prior written permission. 
;
;THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
;"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
;LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
;A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
;HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
;SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
;LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
;DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
;THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
;(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
;OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
function ukmo_unique,vector
;+
; NAME: UKMO_UNIQUE
; TAG: Find unique values in a vector
; PURPOSE: Identify the unique values in a vector
; CALLING SEQUENCE: unique_vector=UKMO_UNIQUE(vector)
; INPUTS: vector -- a vector of values to be examined
; OUTPUTS: unique_vector -- a vector containing one instance of all the
;   different values appearing in vector, in ascending order
; METHOD: (1) find elements which differ from the element before (including
;   the first element); (2) sort them into ascending order, so that repetitions
;   are adjacent; (3) repeat (1) on the reduced vector. The reason for doing
;   the comparison twice is to avoid having to sort the entire input vector
;   (an idea which is due to M.J.Webb).
; MODIFICATION HISTORY: J.M.Gregory 19.10.92
; 		      : M.J.Webb    17.12.92
; 		      : Allowed for case where all elements are the same
; 
;-
;
; IDL_STATUS: 2
;
; Year 2000 compliant: Yes
; Checked by Roger Milton on 23rd August 1998

author_name = '$Author: itam $'
date_name = '$Date: 2012-08-29 17:45:37 +0100 (Wed, 29 Aug 2012) $'
version_name = '$Revision: 317 $'
; RJHD removed for porting.
; @comm_error.inc

vtemp=[0,where([vector(*),vector(n_elements(vector)-1)] $
  ne [vector(0),vector(*)],count)]
if count eq 0 then begin
    vtemp=vector(0)
endif else begin
    vtemp=vector(vtemp)
    vtemp=vtemp(sort(vtemp))
    vtemp=vtemp([0,where([vtemp,vtemp(n_elements(vtemp)-1)] ne [vtemp(0),vtemp])])
endelse
return,vtemp
end
